Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(251)

Unified Diff: public/platform/WebServiceWorker.h

Issue 256723002: Remove the queued states mechanism from ServiceWorker (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: finish removal of stuff Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/serviceworkers/ServiceWorker.cpp ('k') | public/platform/WebServiceWorkerProxy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/platform/WebServiceWorker.h
diff --git a/public/platform/WebServiceWorker.h b/public/platform/WebServiceWorker.h
index cd31d7e899f6730c1d34b558902a1ccce54bf8dc..447f120015b4a55e0717f0c06a4d34b75cadb99d 100644
--- a/public/platform/WebServiceWorker.h
+++ b/public/platform/WebServiceWorker.h
@@ -53,8 +53,9 @@ public:
// WebServiceWorker.
virtual void setProxy(WebServiceWorkerProxy*) { }
- // Sets the state. This should only be called by the WebServiceWorkerProxy.
- virtual void setState(blink::WebServiceWorkerState) { }
+ // Called by this worker's ServiceWorkerProxy when it has become ready or
+ // not ready for state change notifications.
+ virtual void proxyReadyChanged() { }
virtual WebURL scope() const { return WebURL(); }
virtual WebURL url() const { return WebURL(); }
« no previous file with comments | « Source/modules/serviceworkers/ServiceWorker.cpp ('k') | public/platform/WebServiceWorkerProxy.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698